@@ -1,7 +1,7 @@
 """
 Type annotations for migrationhubstrategy service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_migrationhubstrategy/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_migrationhubstrategy/type_defs/)
 
 Usage::
 
@@ -86,6 +86,7 @@ __all__ = (
     "GetPortfolioSummaryResponseTypeDef",
     "GetRecommendationReportDetailsRequestRequestTypeDef",
     "GetRecommendationReportDetailsResponseTypeDef",
+    "GetServerDetailsRequestGetServerDetailsPaginateTypeDef",
     "GetServerDetailsRequestRequestTypeDef",
     "GetServerDetailsResponseTypeDef",
     "GetServerStrategiesRequestRequestTypeDef",
@@ -94,12 +95,16 @@ __all__ = (
     "HeterogeneousTypeDef",
     "HomogeneousTypeDef",
     "ImportFileTaskInformationTypeDef",
+    "ListApplicationComponentsRequestListApplicationComponentsPaginateTypeDef",
     "ListApplicationComponentsRequestRequestTypeDef",
     "ListApplicationComponentsResponseTypeDef",
+    "ListCollectorsRequestListCollectorsPaginateTypeDef",
     "ListCollectorsRequestRequestTypeDef",
     "ListCollectorsResponseTypeDef",
+    "ListImportFileTaskRequestListImportFileTaskPaginateTypeDef",
     "ListImportFileTaskRequestRequestTypeDef",
     "ListImportFileTaskResponseTypeDef",
+    "ListServersRequestListServersPaginateTypeDef",
     "ListServersRequestRequestTypeDef",
     "ListServersResponseTypeDef",
     "ManagementPreferenceTypeDef",
@@ -390,6 +395,14 @@ GetRecommendationReportDetailsResponseTypeDef = TypedDict(
     },
 )
 
+GetServerDetailsRequestGetServerDetailsPaginateTypeDef = TypedDict(
+    "GetServerDetailsRequestGetServerDetailsPaginateTypeDef",
+    {
+        "serverId": str,
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 GetServerDetailsRequestRequestTypeDef = TypedDict(
     "GetServerDetailsRequestRequestTypeDef",
     {
@@ -463,6 +476,17 @@ ImportFileTaskInformationTypeDef = TypedDict(
     },
 )
 
+ListApplicationComponentsRequestListApplicationComponentsPaginateTypeDef = TypedDict(
+    "ListApplicationComponentsRequestListApplicationComponentsPaginateTypeDef",
+    {
+        "applicationComponentCriteria": NotRequired[ApplicationComponentCriteriaType],
+        "filterValue": NotRequired[str],
+        "groupIdFilter": NotRequired[Sequence["GroupTypeDef"]],
+        "sort": NotRequired[SortOrderType],
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListApplicationComponentsRequestRequestTypeDef = TypedDict(
     "ListApplicationComponentsRequestRequestTypeDef",
     {
@@ -484,6 +508,13 @@ ListApplicationComponentsResponseTypeDef = TypedDict(
     },
 )
 
+ListCollectorsRequestListCollectorsPaginateTypeDef = TypedDict(
+    "ListCollectorsRequestListCollectorsPaginateTypeDef",
+    {
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListCollectorsRequestRequestTypeDef = TypedDict(
     "ListCollectorsRequestRequestTypeDef",
     {
@@ -501,6 +532,13 @@ ListCollectorsResponseTypeDef = TypedDict(
     },
 )
 
+ListImportFileTaskRequestListImportFileTaskPaginateTypeDef = TypedDict(
+    "ListImportFileTaskRequestListImportFileTaskPaginateTypeDef",
+    {
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListImportFileTaskRequestRequestTypeDef = TypedDict(
     "ListImportFileTaskRequestRequestTypeDef",
     {
@@ -518,6 +556,17 @@ ListImportFileTaskResponseTypeDef = TypedDict(
     },
 )
 
+ListServersRequestListServersPaginateTypeDef = TypedDict(
+    "ListServersRequestListServersPaginateTypeDef",
+    {
+        "filterValue": NotRequired[str],
+        "groupIdFilter": NotRequired[Sequence["GroupTypeDef"]],
+        "serverCriteria": NotRequired[ServerCriteriaType],
+        "sort": NotRequired[SortOrderType],
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListServersRequestRequestTypeDef = TypedDict(
     "ListServersRequestRequestTypeDef",
     {
